ProtoWasmSandbox

Struct ProtoWasmSandbox 

pub struct ProtoWasmSandbox { /* private fields */ }
A Hyperlight Sandbox with no Wasm run time loaded and no guest module code loaded. This is used to register new host functions that can be called by guest code.

Once all guest functions have been loaded you can call load_runtime to load the Wasm runtime and get a WasmSandbox`.

With that WasmSandbox you can load a Wasm module through the load_module method and get a LoadedWasmSandbox which can then execute functions defined in the Wasm module.

Implementations

Source

impl ProtoWasmSandbox

pub fn load_runtime(self) -> Result<WasmSandbox>

Load the Wasm runtime into the sandbox and return a WasmSandbox that can be cached and used to load a Wasm module resulting in a LoadedWasmSandbox

The LoadedWasmSandbox can be reverted to a WasmSandbox by calling the unload_runtime method. The returned WasmSandbox can be then be cached and used to load a different Wasm module.

pub fn register<Args: ParameterTuple, Output: SupportedReturnType>( &mut self, name: impl AsRef<str>, host_func: impl Into<HostFunction<Output, Args>>, ) -> Result<()>

Register the given host function host_func with self under the given name. Return Ok if the registration succeeded, and a descriptive Err otherwise.

pub fn register_print( &mut self, print_func: impl Into<HostFunction<i32, (String,)>>, ) -> Result<()>

Register the given host printing function print_func with self. Return Ok if the registration succeeded, and a descriptive Err otherwise.